#[non_exhaustive]#[repr(i32)]pub enum AxErrorKind {
Show 46 variants
AddrInUse = 1,
AlreadyConnected = 2,
AlreadyExists = 3,
ArgumentListTooLong = 4,
BadAddress = 5,
BadFileDescriptor = 6,
BadState = 7,
BrokenPipe = 8,
ConnectionRefused = 9,
ConnectionReset = 10,
CrossesDevices = 11,
DirectoryNotEmpty = 12,
FilesystemLoop = 13,
IllegalBytes = 14,
InProgress = 15,
Interrupted = 16,
InvalidData = 17,
InvalidExecutable = 18,
InvalidInput = 19,
Io = 20,
IsADirectory = 21,
NameTooLong = 22,
NoMemory = 23,
NoSuchDevice = 24,
NoSuchDeviceOrAddress = 25,
NoSuchProcess = 26,
NotADirectory = 27,
NotASocket = 28,
NotATty = 29,
NotConnected = 30,
NotFound = 31,
OperationNotPermitted = 32,
OperationNotSupported = 33,
OutOfRange = 34,
PermissionDenied = 35,
ReadOnlyFilesystem = 36,
ResourceBusy = 37,
StorageFull = 38,
TimedOut = 39,
TooManyOpenFiles = 40,
UnexpectedEof = 41,
Unsupported = 42,
WouldBlock = 43,
DestAddrRequired = 44,
MessageTooLong = 45,
WriteZero = 46,
}Expand description
The error kind type used by ArceOS.
Similar to std::io::ErrorKind.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AddrInUse = 1
A socket address could not be bound because the address is already in use elsewhere.
AlreadyConnected = 2
The socket is already connected.
AlreadyExists = 3
An entity already exists, often a file.
ArgumentListTooLong = 4
Program argument list too long.
BadAddress = 5
Bad address.
BadFileDescriptor = 6
Bad file descriptor.
BadState = 7
Bad internal state.
BrokenPipe = 8
Broken pipe
ConnectionRefused = 9
The connection was refused by the remote server.
ConnectionReset = 10
The connection was reset by the remote server.
CrossesDevices = 11
Cross-device or cross-filesystem (hard) link or rename.
DirectoryNotEmpty = 12
A non-empty directory was specified where an empty directory was expected.
FilesystemLoop = 13
Loop in the filesystem or IO subsystem; often, too many levels of symbolic links.
IllegalBytes = 14
Illegal byte sequence.
InProgress = 15
The operation was partially successful and needs to be checked later on due to not blocking.
Interrupted = 16
This operation was interrupted.
InvalidData = 17
Data not valid for the operation were encountered.
Unlike InvalidInput, this typically means that the operation
parameters were valid, however the error was caused by malformed
input data.
For example, a function that reads a file into a string will error with
InvalidData if the file’s contents are not valid UTF-8.
InvalidExecutable = 18
Invalid executable format.
InvalidInput = 19
Invalid parameter/argument.
Io = 20
Input/output error.
IsADirectory = 21
The filesystem object is, unexpectedly, a directory.
NameTooLong = 22
Filename is too long.
NoMemory = 23
Not enough space/cannot allocate memory.
NoSuchDevice = 24
No such device.
NoSuchDeviceOrAddress = 25
No such device or address (ENXIO). Linux uses ENXIO for: opening a UNIX-domain-socket file, opening a FIFO O_WRONLY|O_NONBLOCK with no reader, opening a device-special file with no underlying device.
NoSuchProcess = 26
No such process.
NotADirectory = 27
A filesystem object is, unexpectedly, not a directory.
NotASocket = 28
The specified entity is not a socket.
NotATty = 29
Not a typewriter.
NotConnected = 30
The network operation failed because it was not connected yet.
NotFound = 31
The requested entity is not found.
OperationNotPermitted = 32
Operation not permitted.
OperationNotSupported = 33
Operation not supported.
OutOfRange = 34
Result out of range.
PermissionDenied = 35
The operation lacked the necessary privileges to complete.
ReadOnlyFilesystem = 36
The filesystem or storage medium is read-only, but a write operation was attempted.
ResourceBusy = 37
Device or resource is busy.
StorageFull = 38
The underlying storage (typically, a filesystem) is full.
TimedOut = 39
The I/O operation’s timeout expired, causing it to be canceled.
TooManyOpenFiles = 40
The process has too many files open.
UnexpectedEof = 41
An error returned when an operation could not be completed because an “end of file” was reached prematurely.
Unsupported = 42
This operation is unsupported or unimplemented.
WouldBlock = 43
The operation needs to block to complete, but the blocking operation was requested to not occur.
DestAddrRequired = 44
Destination address required (sendto/sendmsg on unconnected socket without specifying a target address).
MessageTooLong = 45
Message too long (sendto/sendmsg with datagram exceeding socket buffer or protocol size limit).
WriteZero = 46
An error returned when an operation could not be completed because a
call to write() returned Ok(0).
Implementations