ax-errno
Generic error code representation
English | 中文
Introduction
ax-errno provides Generic error code representation. It is maintained as part of the TGOSKits component set and is intended for Rust projects that integrate with ArceOS, AxVisor, or related low-level systems software.
ax-errno was derived from https://github.com/arceos-org/axerrno
Quick Start
Installation
Add this crate to your Cargo.toml:
[dependencies]
ax-errno = "0.4.2"Run Check and Test
# Enter the crate directory
cd components/axerrno
# Format code
cargo fmt --all
# Run clippy
cargo clippy --all-targets --all-features
# Run tests
cargo test --all-features
# Build documentation
cargo doc --no-depsIntegration
Example
use ax_errno as _;
fn main() {
// Integrate `ax-errno` into your project here.
}Documentation
Generate and view API documentation:
cargo doc --no-deps --openOnline documentation: docs.rs/ax-errno
Contributing
- Fork the repository and create a branch
- Run local format and checks
- Run local tests relevant to this crate
- Submit a PR and ensure CI passes
License
Licensed under the Apache License, Version 2.0. See LICENSE for details.
Macros
- ax_bail
- Throws an error of type
AxErrorwith the given error code, optionally with a message. - ax_err
- Convenience method to construct an
Err(AxError)type while printing a warning message. - ax_
err_ type - Convenience method to construct an
AxErrortype while printing a warning message. - ensure
- Ensure a condition is true. If it is not, return from the function with an error.
Structs
- AxError
- The error type used by ArceOS.
Enums
- AxError
Kind - The error kind type used by ArceOS.
- Linux
Error - Linux specific error codes defined in
errno.h.
Type Aliases
- AxResult
- A specialized
Resulttype withAxErroras the error type. - Linux
Result - A specialized
Resulttype withLinuxErroras the error type.